==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/ArrayCore/src/ActiveFKWorker.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2019-12-09
**  Copyright: 2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef ACTIVEFKWORKER_H
#define ACTIVEFKWORKER_H

#include "FKWorker.h"
#include "ArrayCoreDLLExport.h"
#include "ActiveFKParameters.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT ActiveFKWorker : public FKWorker
  {
  public:
    ActiveFKWorker(const ArraySelection * array,
                   const ActiveFKParameters * param,
                   const SeismicEvent * source,
                   IrregularGrid2D * grid);
    ~ActiveFKWorker();
  protected:
    virtual void process(const QVector<int>& blocks);
  private:
    IrregularGrid2D * _grid;
  };

} // namespace ArrayCore

#endif // ACTIVEFKWORKER_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/ArrayCore/src/ActiveFKWorker.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2019-12-09
**  Copyright: 2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef ACTIVEFKWORKER_H
#define ACTIVEFKWORKER_H

#include "FKWorker.h"
#include "ArrayCoreDLLExport.h"
#include "ActiveFKParameters.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT ActiveFKWorker : public FKWorker
  {
  public:
    ActiveFKWorker(const ArraySelection * array,
                   const ActiveFKParameters * param,
                   const SeismicEvent * source,
                   IrregularGrid2D * grid);
    ~ActiveFKWorker();

    bool setGrid(FKCache * cache);
  protected:
    void process(const VectorList<int>& blocks);
  private:
    IrregularGrid2D * _grid;
    AbstractFKFunction * _function;
  };

} // namespace ArrayCore

#endif // ACTIVEFKWORKER_H
